@@ -16,7 +16,7 @@
 # Licence:: CC-BY-SA 2.0 or GPL-3+
 #
 
-VERSION = "5.4.7 (Exclusion)"
+VERSION = "5.4.8 (Inclusion)"
 
 puts "CeWL #{VERSION} Robin Wood (robin@digi.ninja) (https://digi.ninja/)\n"
 
@@ -813,7 +813,11 @@ catch :ctrl_c do
 				allow
 			end
 
-			s.on :success do |a_url, resp, prior_url|
+			# This was :success so only the content from a 200 was processed.
+			# Updating it to :every so that the content of all pages gets processed
+			# so you can grab things off 404s or text leaked on redirect and error pages.
+
+			s.on :every do |a_url, resp, prior_url|
 				if verbose
 					if prior_url.nil?
 						puts "Visiting: #{a_url}, got response code #{resp.code}"
